/*
 * Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
 * Departamento de Informatica - Universidade Federal do Parana
 *
 * This file is part of blendb.
 *
 * blendb is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * blendb is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with blendb.  If not, see <http://www.gnu.org/licenses/>.
 */

import { expect } from "chai";
import { Log } from "./log";

describe("log class", () => {

    it("should modifiy loglevel to error if wrong level", () => {
        process.env.BLENDB_LOG_LEVEL = "test";
        const logLevelWrong = new Log();
        expect(logLevelWrong.getLogLevel()).to.be.equals("error");
    });

    it("should modifiy loglevel to error if empty level", () => {
        process.env.BLENDB_LOG_LEVEL = "";
        const logLevelEmpty = new Log();
        expect(logLevelEmpty.getLogLevel()).to.be.equals("error");
    });

    it("should modifiy logFile to stderr if empty file", () => {
        process.env.BLENDB_LOG_FILE = "";
        const LogFileEmpty = new Log();
        expect(LogFileEmpty.getLogFile()).to.be.equals("stderr");
    });

    it("should modifiy logFile to stderr if file does not exist", () => {
        process.env.BLENDB_LOG_FILE = "norepo/test/shalnotexist";
        const LogFileEmpty = new Log();
        expect(LogFileEmpty.getLogFile()).to.be.equals("stderr");
    });

});
